@@ -1,7 +1,7 @@
 package App::xsum;
 
 our $DATE = '2019-09-12'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,10 +89,22 @@ _
             url => 'prog:sha1sum',
             summary => 'Unix utility',
         },
+        {
+            url => 'prog:sha224sum',
+            summary => 'Unix utility',
+        },
         {
             url => 'prog:sha256sum',
             summary => 'Unix utility',
         },
+        {
+            url => 'prog:sha384sum',
+            summary => 'Unix utility',
+        },
+        {
+            url => 'prog:sha512sum',
+            summary => 'Unix utility',
+        },
     ],
     examples => [
         {
@@ -202,7 +214,7 @@ sub xsum {
                     warn "$entry->{file}: Cannot compute digest: $digest_res->[1]\n";
                     next ENTRY;
                 }
-                if ($digest_res->[2] eq $entry->{digest}) {
+                if (lc($digest_res->[2]) eq lc($entry->{digest})) {
                     print "$entry->{file}: OK\n";
                     $num_success++;
                 } else {
@@ -228,7 +240,7 @@ sub xsum {
                 warn "$file: Cannot compute digest: $digest_res->[1]\n";
                 next;
             }
-            if ($digest_res->[2] eq $args{checksums}[$i]) {
+            if (lc($digest_res->[2]) eq lc($args{checksums}[$i])) {
                 print "$file: OK\n";
                 $num_success++;
             } else {
@@ -275,7 +287,7 @@ App::xsum - Compute and check file checksums/digests (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.006 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
+This document describes version 0.007 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
 
 =head1 SYNOPSIS
 
@@ -375,10 +387,15 @@ L<md5sum>. Unix utility.
 
 L<sha1sum>. Unix utility.
 
+L<sha224sum>. Unix utility.
+
 L<sha256sum>. Unix utility.
 
-Backend module: L<File::Digest>, which in turn uses L<Digest::CRC>,
-L<Digest::MD5>, and L<Digest::SHA>.
+L<sha384sum>. Unix utility.
+
+L<sha512sum>. Unix utility.
+
+L<sum> from L<PerlPowerTools> (which only supports older algorithms like CRC32).
 
 =head1 AUTHOR
 
